@@ -11,10 +11,10 @@ migrate = Migrate()
 
 
 def create_app():
-    app = Flask('Habref')
-    app.config.from_envvar('HABREF_SETTINGS')
+    app = Flask("Habref")
+    app.config.from_envvar("HABREF_SETTINGS")
     ma.init_app(app)
     db.init_app(app)
-    migrate.init_app(app, db, directory=Path(__file__).parent / 'migrations')
-    app.register_blueprint(routes, url_prefix='/habref')
+    migrate.init_app(app, db, directory=Path(__file__).parent / "migrations")
+    app.register_blueprint(routes, url_prefix="/habref")
     return app
