@@ -5,22 +5,21 @@ from flask_marshmallow import Marshmallow
 from flask_sqlalchemy import SQLAlchemy
 
 
-
-db_path = environ.get('FLASK_SQLALCHEMY_DB')
+db_path = environ.get("FLASK_SQLALCHEMY_DB")
 if db_path:
-    db_module_name, db_object_name = db_path.rsplit('.', 1)
+    db_module_name, db_object_name = db_path.rsplit(".", 1)
     db_module = import_module(db_module_name)
     db = getattr(db_module, db_object_name)
 else:
     db = SQLAlchemy()
 
-marsmallow_path = environ.get('FLASK_MARSHMALLOW')
+marsmallow_path = environ.get("FLASK_MARSHMALLOW")
 if marsmallow_path:
-    ma_module_name, ma_object_name = marsmallow_path.rsplit('.', 1)
+    ma_module_name, ma_object_name = marsmallow_path.rsplit(".", 1)
     ma_module = import_module(ma_module_name)
     ma = getattr(ma_module, ma_object_name)
 else:
     ma = Marshmallow()
 
 
-__all__ = ['db', 'ma']
+__all__ = ["db", "ma"]
